@@ -1,3 +1,4 @@
+import itertools
 from django import forms
 from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
 from django.conf import settings
@@ -56,26 +57,28 @@ class BaseSearchForm(forms.Form):
         """
         This returns the DB objects that matches the search
         """
-        if self.in_search_mode():
-            objects = self.search()
-            # reduce the results based on the q field
-            if self.cleaned_data.get("q"):
-                objects = objects.query(content__match=self.cleaned_data['q'])
-        else:
-            objects = self.queryset()
+        if not self.in_search_mode():
+            return self.queryset()
 
-        if self.in_search_mode():
-            # if we are doing a search, we need to swap out the paginator's
-            # object_list with the actual preparation objects (since those aren't
-            # stored in the search index). Build up a dict that has the object
-            # pk as a key, and the order of the object as the value, so we can
-            # sort the objects by it
-            pk_lookup = dict((int(search_result.pk), i) for i, search_result in enumerate(objects))
-            objects = self.queryset().filter(pk__in=pk_lookup.keys())
-            # we need to sort the objects based on the order they were returned
-            # by elasticsearch
-            if self.sort_by_relevance:
-                objects = sorted(objects, key=lambda item: pk_lookup[item.pk])
+        # we are doing a search
+        objects = self.search()
+        # reduce the results based on the q field
+        if self.cleaned_data.get("q"):
+            objects = objects.query(content__match=self.cleaned_data['q'])
+
+        # get ALL the pk values for the matches
+        pks = objects.values_list("pk").everything()
+        # Create a mapping that maps a pk, to the position the object should
+        # appear in a list. This allows us to order things by relevance.
+        # The [0][0] index is used because ES (for some reason) turns fields
+        # into lists when you use the `fields` clause on the query, which
+        # implicitly happens when we used the .values_list method
+        pk_lookup = dict((int(pk[0][0]), i) for i, pk in enumerate(pks))
+        objects = self.queryset().filter(pk__in=pk_lookup.keys())
+        # we need to sort the objects based on the order they were returned
+        # by elasticsearch
+        if self.sort_by_relevance:
+            objects = sorted(objects, key=lambda item: pk_lookup[item.pk])
 
         return objects
 
