@@ -1,3 +1,4 @@
+from __future__ import print_function
 import elasticsearch
 from django.conf import settings
 from django.core.management.base import BaseCommand, CommandError
@@ -8,6 +9,7 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         clear_index()
+
         for model_class, index in index_registry.items():
             model = index.model
             es().indices.put_mapping(
@@ -19,8 +21,10 @@ class Command(BaseCommand):
             )
 
             es().indices.refresh(index=settings.ELASTIC_SEARCH_INDEX)
-            for obj in model.objects.all():
-                print "indexing %s pk = %d" % (obj.__class__.__name__, obj.pk)
+            #for obj in model.objects.all():
+            for obj in index.get_queryset():
+            #for obj in model.objects.filter(**(index.filter_params)):
+                print("indexing %s pk = %d" % (obj.__class__.__name__, obj.pk))
                 # TODO use a bulk update for this
                 make_searchable(obj, refresh=False)
             es().indices.refresh(index=settings.ELASTIC_SEARCH_INDEX)
